﻿/*
DateMenus.ahk by Jack Dunning, November 19, 2015
Written for the blog https://wordpress.com/stats/day/jacksautohotkeyblog.wordpress.com

November 19, 2015—Updated to track original editing window.

More free AutoHotkey scripts can be found at:
http://www.computoredge.com/AutoHotkey/Free_AutoHotkey_Scripts_and_Apps_for_Learning_and_Generating_Ideas.html

Beginning AutoHotkey books are available at:
http://www.computoredgebooks.com/AutoHotkey-E-Books_c19.htm?sourceCode=DateMenus.ahk

This script consists of three hotstings, each activated by typing the word "date" (no caps) and terminated with a separate A_End_Char:
    A_End_Char = - (hyphen)                Today's date and time is offered.
    A_End_Char = ; (semicolon)             The MonthCal GUI is opened.
    A_End_Char = ] (close square bracket)  The DateTime GUI is opened.
*/

#NoEnv  ; Recommended for performance and compatibility with future AutoHotkey releases.
SetWorkingDir %A_ScriptDir%  ; Ensures a consistent starting directory.


:B0C:date::
  ActWin := WinActive("A") ; for tracking original window—also works with  WinGet, ActWin, ID, A
;  MsgBox, %ActWin%    ; for testing purposes only
  If A_EndChar = -
  {
    SendInput {Backspace 5}
    Date := A_Now
    List := DateFormats(Date)
    TextMenuDate(List)
  }
  Else If A_EndChar = `;
  {
    SendInput {Backspace 5}
    IfWinExist, Select Date
       Gui AddDate:Destroy
    Gui AddDate:+AlwaysOnTop  ; visible until selection
    Gui, AddDate:Add, MonthCal, vDayPick ;r4 w-3
    Gui, AddDate:Add, Button, Default, Submit
    Gui, AddDate:Show,, Select Date
  }
  Else If A_EndChar = ]
  {
    SendInput {Backspace 5}
    IfWinExist, Select Date
      Gui AddDate:Destroy
    Gui AddDate:+AlwaysOnTop
    Gui, AddDate:Add, DateTime, vDayPick, hh:mm tt, dddd MMMM d, yyyy
    Gui, AddDate:Add, Button, Default, Submit
    Gui, AddDate:Show,, Select Date or Time
  }
Return

AddDateButtonSubmit:
  Gui AddDate:Submit
  Gui AddDate:Destroy
  List := DateFormats(DayPick)
  TextMenuDate(List)
Return


AddDateGuiClose:
  Gui AddDate:Destroy
Return

DateFormats(Date)
{
  FormatTime, OutputVar , %Date%, h:mm tt ;12 hour clock
  List := OutputVar
  FormatTime, OutputVar , %Date%, HH:mm  ;24 hour clock
  List := List . "|" . OutputVar
  FormatTime, OutputVar , %Date%, ShortDate ; 11/5/2015
  List := List . "|" . OutputVar
  FormatTime, OutputVar , %Date%, MMM. d, yyyy
  List := List . "|" . OutputVar
  FormatTime, OutputVar , %Date%, MMMM d, yyyy
  List := List . "|" . OutputVar
  FormatTime, OutputVar , %Date%, LongDate
  List := List . "|" . OutputVar
  FormatTime, OutputVar, %Date%, h:mm tt, dddd, MMMM d, yyyy
  List := List . "|" . OutputVar
  FormatTime, OutputVar, %Date%, dddd MMMM d, yyyy hh:mm:ss tt
  List := List . "|" . OutputVar
  Return List
}

TextMenuDate(TextOptions)
{
 StringSplit, MenuItems, TextOptions , |
 Loop %MenuItems0%
  {
    Item := MenuItems%A_Index%
    Menu, MyMenu, add, %Item%, MenuAction
  }
 Menu, MyMenu, Show
 Menu, MyMenu, DeleteAll
}

MenuAction:
 WinActivate, ahk_id %ActWin%  ;activate original window
 If A_ThisMenuItem Is Alpha 
 {
   SendInput %A_ThisMenuItem%{Raw}%A_EndChar%
 }
 Else
   SendInput %A_ThisMenuItem%
Return
